@@ -9,10 +9,8 @@ echo "# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
 echo "#"
 echo "#"
 
-which aap >/dev/null && echo "You seem to have A-A-P, I recommend you press CRTL-C and read INSTALL on how to use this instead." && echo "Press return to continue anyway..." && read
-
 make -j2 || exit 1;
-strip -s src/ccbuild;
+strip -s ccbuild;
 
 function binDir()
 {
