@@ -1,5 +1,6 @@
 /*
   This file is part of ccbuild.
+  Copyright (C) 2013  A. Bram Neijt <bneijt@gmail.com>
 
   ccbuild is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -17,16 +18,17 @@
 
 #include "MD5Info.ih"
 
-std::string const &MD5Info::old(std::string const &filename)
-{
-  d_oldLock.set();
-	bool available = (d_old.count(filename) > 0);
-  d_oldLock.unset();
-	//Try to load it from disk
-	if(not available)
-  	load(filename);
-	
-  OpenMP::ScopedLock lock(d_oldLock);
-  _debugLevel3("Found old content hash: " << d_old[filename]);
-	return d_old[filename];
+std::string const &MD5Info::old(std::string const &filename) {
+    d_oldLock.set();
+    bool available = (d_old.count(filename) > 0);
+    d_oldLock.unset();
+
+    //Try to load it from disk
+    if(not available) {
+        load(filename);
+    }
+
+    OpenMP::ScopedLock lock(d_oldLock);
+    _debugLevel3("Found old content hash: " << d_old[filename]);
+    return d_old[filename];
 }
