@@ -17,37 +17,36 @@
 
 #include "compiler.ih"
 
-int Compiler::ar(std::string target) const
-{
-	//Construct ar command
-	//  ar [--plugin name] [-X32_64] [-]p[mod [relpos] [count]] archive [member...]
-  ostringstream command("ar qcs ", ios::ate);
-  command << " " << target;
+int Compiler::ar(std::string target) const {
+    //Construct ar command
+    //  ar [--plugin name] [-X32_64] [-]p[mod [relpos] [count]] archive [member...]
+    ostringstream command("ar qcs ", ios::ate);
+    command << " " << target;
 
-  __foreach(obj, d_objects)
+    __foreach(obj, d_objects)
     command << " \"" << (*obj) << "\"";
 
-	cls();
-	
-  //Remove the output file
-  FileSystem::rmIfExists(target);
-  cerrLock.set();
-  cerr << "[AR] " << target << "\n";
-  cerrLock.unset();
+    cls();
 
-	//Run ar command
-	int retValue = System::system(command.str().c_str());
-
-
-  if(retValue != 0)
-  {
+    //Remove the output file
+    FileSystem::rmIfExists(target);
     cerrLock.set();
-    cerr << "ccbuild: Non zero exit status (" << retValue << ")\n";
+    cerr << "[AR] " << target << "\n";
     cerrLock.unset();
 
-    if(!Options::brute)
-    	throw Problem(Problem::Subfailure, "Ar failed to create " + target, retValue);
-  }
+    //Run ar command
+    int retValue = System::system(command.str().c_str());
 
-  return retValue;
+
+    if(retValue != 0) {
+        cerrLock.set();
+        cerr << "ccbuild: Non zero exit status (" << retValue << ")\n";
+        cerrLock.unset();
+
+        if(!Options::brute) {
+            throw Problem(Problem::Subfailure, "Ar failed to create " + target, retValue);
+        }
+    }
+
+    return retValue;
 }
