@@ -16,22 +16,20 @@
 */
 #include "fileSystem.ih"
 
-string FileSystem::cwd()
-{
+string FileSystem::cwd() {
 #ifdef _GNU_SOURCE
-  char *cwd = get_current_dir_name();
-  std::string wd(cwd);
-  free(cwd);
-  return wd;
+    char *cwd = get_current_dir_name();
+    std::string wd(cwd);
+    free(cwd);
+    return wd;
 #else
-  #ifndef PATH_MAX
-  #define PATH_MAX 1024
-  #endif
+#ifndef PATH_MAX
+#define PATH_MAX 1024
+#endif
     char *cwd = new char[PATH_MAX];
-    if(getcwd(cwd, PATH_MAX) == 0)
-    {
-      delete[] cwd;
-      throw Problem(Problem::Unable, "Unable to correctly get the current working directory");
+    if(getcwd(cwd, PATH_MAX) == 0) {
+        delete[] cwd;
+        throw Problem(Problem::Unable, "Unable to correctly get the current working directory");
     }
     std::string wd(cwd);
     delete[] cwd;
