@@ -20,7 +20,7 @@
 bool FileSystem::touch(std::string const &filename) {
     OpenMP::ScopedLock asdf(fsLock);
     ofstream file(filename.c_str(), ios::app);
-    bool succes = file.is_open();
+    bool success = file.is_open();
     file.close();
-    return succes;
+    return success;
 }
