@@ -16,14 +16,12 @@
 */
 
 #include "resolver.ih"
-void Resolver::destroy()
-{
-  OpenMP::ScopedLock instantiateLock(s_instanceLock);
-	if(s_instance) {
-		delete s_instance;
-	}
-	else {
-		_debugLevel1("Already destroyed!!");
-	}
-	s_instance = 0;
+void Resolver::destroy() {
+    OpenMP::ScopedLock instantiateLock(s_instanceLock);
+    if(s_instance) {
+        delete s_instance;
+    } else {
+        _debugLevel1("Already destroyed!!");
+    }
+    s_instance = 0;
 }
