@@ -16,13 +16,11 @@
 */
 
 #include "source.ih"
-std::string Source::basenameWithoutExtension() const
-{
-  std::string basename = FileSystem::baseName(d_filename);
-  std::string::size_type i = basename.rfind('.');
-  if(i == string::npos)
-  {
-    throw Problem(Problem::Missing, "Can not find extension in a file which was requested without extension. Basename: " + basename);
-  }
-  return basename.substr(0, i);
+std::string Source::basenameWithoutExtension() const {
+    std::string basename = FileSystem::baseName(d_filename);
+    std::string::size_type i = basename.rfind('.');
+    if(i == string::npos) {
+        throw Problem(Problem::Missing, "Can not find extension in a file which was requested without extension. Basename: " + basename);
+    }
+    return basename.substr(0, i);
 }
