@@ -1,5 +1,6 @@
 /*
   This file is part of ccbuild.
+  Copyright (C) 2013  A. Bram Neijt <bneijt@gmail.com>
 
   ccbuild is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -15,21 +16,16 @@
   along with ccbuild.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-
-
-
-
-
-
 #include "source.ih"
 
-bool Source::stale()
-{
-	if(!FileSystem::fileExists(filename()))
-		return true;
+bool Source::stale() {
+    if(!FileSystem::fileExists(filename())) {
+        return true;
+    }
 
-	if(Options::md5)
-		return changed();
+    if(Options::md5) {
+        return changed();
+    }
 
-	return d_modTime == 0 || d_modTime != FileSystem::modTime(filename());
+    return d_modTime == 0 || d_modTime != FileSystem::modTime(filename());
 }
