@@ -16,8 +16,9 @@
 */
 
 #include "sourceScanner.ih"
-SourceScanner::SourceScanner(istream * newYyin)
+
+SourceScanner::SourceScanner(istream *newYyin)
     :
     d_hasMainFunction(false) {
-    switch_streams(newYyin, yyout);
+    switch_streams(*newYyin, yyout);
 }
