@@ -17,10 +17,10 @@
 
 #include "sources.ih"
 
-Sources &Sources::getInstance()
-{
-  OpenMP::ScopedLock instantiateLock(s_instanceLock);
-	if(s_instance == 0)
-		s_instance = new Sources();
-	return *s_instance;
+Sources &Sources::getInstance() {
+    OpenMP::ScopedLock instantiateLock(s_instanceLock);
+    if(s_instance == 0) {
+        s_instance = new Sources();
+    }
+    return *s_instance;
 }
