@@ -1,5 +1,6 @@
 /*
   This file is part of ccbuild.
+  Copyright (C) 2013  A. Bram Neijt <bneijt@gmail.com>
 
   ccbuild is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -16,7 +17,6 @@
 */
 
 #include "string.ih"
-void String::toUpper()
-{
-	transform(this->begin(), this->end(), this->begin(), static_cast<int (*)(int)>(std::toupper));	
+void String::toUpper() {
+    transform(this->begin(), this->end(), this->begin(), static_cast<int (*)(int)>(std::toupper));
 }
